@@ -1,6 +1,9 @@
 """Test for libtmux Window object."""
 
+from __future__ import annotations
+
 import logging
+import pathlib
 import shutil
 import time
 import typing as t
@@ -9,6 +12,7 @@ import pytest
 
 from libtmux import exc
 from libtmux._internal.query_list import ObjectDoesNotExist
+from libtmux._internal.types import StrPath
 from libtmux.common import has_gte_version, has_lt_version, has_lte_version
 from libtmux.constants import (
     PaneDirection,
@@ -17,9 +21,11 @@ from libtmux.constants import (
 )
 from libtmux.pane import Pane
 from libtmux.server import Server
-from libtmux.session import Session
 from libtmux.window import Window
 
+if t.TYPE_CHECKING:
+    from libtmux.session import Session
+
 logger = logging.getLogger(__name__)
 
 
@@ -69,7 +75,7 @@ def test_fresh_window_data(session: Session) -> None:
     assert isinstance(session.server, Server)
     # len(session.active_window.panes))
 
-    assert len(session.windows), 1
+    assert len(session.windows) == 1
     assert len(session.active_window.panes) == 1
     for w in session.windows:
         assert isinstance(w, Window)
@@ -207,33 +213,53 @@ def test_split_size(session: Session) -> None:
         assert pane.pane_width == str(int(window_width_before * 0.1))
 
 
+class WindowRenameFixture(t.NamedTuple):
+    """Test fixture for window rename functionality."""
+
+    test_id: str
+    window_name_before: str
+    window_name_input: str
+    window_name_after: str
+
+
+WINDOW_RENAME_FIXTURES: list[WindowRenameFixture] = [
+    WindowRenameFixture(
+        test_id="rename_with_spaces",
+        window_name_before="test",
+        window_name_input="ha ha ha fjewlkjflwef",
+        window_name_after="ha ha ha fjewlkjflwef",
+    ),
+    WindowRenameFixture(
+        test_id="rename_with_escapes",
+        window_name_before=r"hello \ wazzup 0",
+        window_name_input=r"hello \ wazzup 0",
+        window_name_after=r"hello \\ wazzup 0",
+    ),
+]
+
+
 @pytest.mark.parametrize(
-    ("window_name_before", "window_name_after"),
-    [("test", "ha ha ha fjewlkjflwef"), ("test", "hello \\ wazzup 0")],
+    list(WindowRenameFixture._fields),
+    WINDOW_RENAME_FIXTURES,
+    ids=[test.test_id for test in WINDOW_RENAME_FIXTURES],
 )
 def test_window_rename(
     session: Session,
+    test_id: str,
     window_name_before: str,
+    window_name_input: str,
     window_name_after: str,
 ) -> None:
     """Test Window.rename_window()."""
-    window_name_before = "test"
-    window_name_after = "ha ha ha fjewlkjflwef"
-
     session.set_option("automatic-rename", "off")
     window = session.new_window(window_name=window_name_before, attach=True)
 
     assert window == session.active_window
     assert window.window_name == window_name_before
 
-    window.rename_window(window_name_after)
+    window.rename_window(window_name_input)
 
     window = session.active_window
-
-    assert window.window_name == window_name_after
-
-    window = session.active_window
-
     assert window.window_name == window_name_after
 
 
@@ -298,7 +324,7 @@ def test_show_window_option_unknown(session: Session) -> None:
     """Window.show_window_option raises UnknownOption for bad option key."""
     window = session.new_window(window_name="test_window")
 
-    cmd_exception: t.Type[exc.OptionError] = exc.UnknownOption
+    cmd_exception: type[exc.OptionError] = exc.UnknownOption
     if has_gte_version("3.0"):
         cmd_exception = exc.InvalidOption
     with pytest.raises(cmd_exception):
@@ -381,24 +407,42 @@ def test_empty_window_name(session: Session) -> None:
     assert "''" in cmd.stdout
 
 
+class WindowSplitEnvironmentFixture(t.NamedTuple):
+    """Test fixture for window split with environment variables."""
+
+    test_id: str
+    environment: dict[str, str]
+
+
+WINDOW_SPLIT_ENV_FIXTURES: list[WindowSplitEnvironmentFixture] = [
+    WindowSplitEnvironmentFixture(
+        test_id="single_env_var",
+        environment={"ENV_VAR": "pane"},
+    ),
+    WindowSplitEnvironmentFixture(
+        test_id="multiple_env_vars",
+        environment={"ENV_VAR_1": "pane_1", "ENV_VAR_2": "pane_2"},
+    ),
+]
+
+
 @pytest.mark.skipif(
     has_lt_version("3.0"),
     reason="needs -e flag for split-window which was introduced in 3.0",
 )
 @pytest.mark.parametrize(
-    "environment",
-    [
-        {"ENV_VAR": "pane"},
-        {"ENV_VAR_1": "pane_1", "ENV_VAR_2": "pane_2"},
-    ],
+    list(WindowSplitEnvironmentFixture._fields),
+    WINDOW_SPLIT_ENV_FIXTURES,
+    ids=[test.test_id for test in WINDOW_SPLIT_ENV_FIXTURES],
 )
 def test_split_with_environment(
     session: Session,
-    environment: t.Dict[str, str],
+    test_id: str,
+    environment: dict[str, str],
 ) -> None:
     """Verify splitting window with environment variables."""
     env = shutil.which("env")
-    assert env is not None, "Cannot find usable `env` in Path."
+    assert env is not None, "Cannot find usable `env` in PATH."
 
     window = session.new_window(window_name="split_with_environment")
     pane = window.split(
@@ -457,9 +501,9 @@ def test_split_with_environment_logs_warning_for_old_tmux(
         environment={"ENV_VAR": "pane"},
     )
 
-    assert any(
-        "Environment flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Environment flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
 
 
 @pytest.mark.skipif(
@@ -592,10 +636,123 @@ def test_new_window_with_direction_logs_warning_for_old_tmux(
         direction=WindowDirection.After,
     )
 
-    assert any(
-        "Window target ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Window target ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
 
-    assert any(
-        "Direction flag ignored" in record.msg for record in caplog.records
-    ), "Warning missing"
+    assert any("Direction flag ignored" in record.msg for record in caplog.records), (
+        "Warning missing"
+    )
+
+
+def test_window_context_manager(session: Session) -> None:
+    """Test Window context manager functionality."""
+    with session.new_window() as window:
+        pane = window.split()
+        assert window in session.windows
+        assert pane in window.panes
+        assert len(window.panes) == 2  # Initial pane + new pane
+
+    # Window should be killed after exiting context
+    assert window not in session.windows
+
+
+class StartDirectoryTestFixture(t.NamedTuple):
+    """Test fixture for start_directory parameter testing."""
+
+    test_id: str
+    start_directory: StrPath | None
+    description: str
+
+
+START_DIRECTORY_TEST_FIXTURES: list[StartDirectoryTestFixture] = [
+    StartDirectoryTestFixture(
+        test_id="none_value",
+        start_directory=None,
+        description="None should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="empty_string",
+        start_directory="",
+        description="Empty string should not add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="user_path",
+        start_directory="{user_path}",
+        description="User path should add -c flag",
+    ),
+    StartDirectoryTestFixture(
+        test_id="relative_path",
+        start_directory="./relative/path",
+        description="Relative path should add -c flag",
+    ),
+]
+
+
+@pytest.mark.parametrize(
+    list(StartDirectoryTestFixture._fields),
+    START_DIRECTORY_TEST_FIXTURES,
+    ids=[test.test_id for test in START_DIRECTORY_TEST_FIXTURES],
+)
+def test_split_start_directory(
+    test_id: str,
+    start_directory: StrPath | None,
+    description: str,
+    session: Session,
+    monkeypatch: pytest.MonkeyPatch,
+    tmp_path: pathlib.Path,
+    user_path: pathlib.Path,
+) -> None:
+    """Test Window.split start_directory parameter handling."""
+    monkeypatch.chdir(tmp_path)
+
+    window = session.new_window(window_name=f"test_window_split_{test_id}")
+
+    # Format path placeholders with actual fixture values
+    actual_start_directory = start_directory
+    expected_path = None
+
+    if start_directory and str(start_directory) not in ["", "None"]:
+        if "{user_path}" in str(start_directory):
+            # Replace placeholder with actual user_path
+            actual_start_directory = str(start_directory).format(user_path=user_path)
+            expected_path = str(user_path)
+        elif str(start_directory).startswith("./"):
+            # For relative paths, use tmp_path as base
+            temp_dir = tmp_path / "relative" / "path"
+            temp_dir.mkdir(parents=True, exist_ok=True)
+            actual_start_directory = str(temp_dir)
+            expected_path = str(temp_dir.resolve())
+
+    # Should not raise an error
+    new_pane = window.split(start_directory=actual_start_directory)
+
+    assert new_pane in window.panes
+    assert len(window.panes) == 2
+
+    # Verify working directory if we have an expected path
+    if expected_path:
+        new_pane.refresh()
+        assert new_pane.pane_current_path is not None
+        actual_path = str(pathlib.Path(new_pane.pane_current_path).resolve())
+        assert actual_path == expected_path
+
+
+def test_split_start_directory_pathlib(
+    session: Session, user_path: pathlib.Path
+) -> None:
+    """Test Window.split accepts pathlib.Path for start_directory."""
+    window = session.new_window(window_name="test_window_split_pathlib")
+
+    # Pass pathlib.Path directly to test pathlib.Path acceptance
+    new_pane = window.split(start_directory=user_path)
+
+    assert new_pane in window.panes
+    assert len(window.panes) == 2
+
+    # Verify working directory
+    new_pane.refresh()
+    assert new_pane.pane_current_path is not None
+    actual_path = str(pathlib.Path(new_pane.pane_current_path).resolve())
+    expected_path = str(user_path.resolve())
+    assert actual_path == expected_path
